@@ -273,9 +273,9 @@ class RESTAPI :
         response = self.get_summoner_by_id(summoner['id'])
         if len(response) == 0 :
             api_url = URL['summoners'].format(url='/')
-            self.request_update(api_url, body)
+            self.request_post(api_url, body)
         else :
-            api_url = URL['summoners'].format(url='/{id}'.format(id=summoner['id']))
+            api_url = URL['summoners'].format(url='/{id}'.format(id=body['id']))
             self.request_update(api_url, body)
         return True
 
